import sys
from numpy import *
import os

def getRawData(rawDataFilename):
    data = [];
    lastrow = None;
    sample = 0;
    maxseconds = 16777216;
    with open(rawDataFilename,'r') as f:
        for line in f:
            sample += 1;
            items = line.split(',');
            month = int(items[1]);
            day = int(items[2]);
            dayseconds = int(items[3]) * 3600 + int(items[4]) * 60 + int(items[5]);
            asecs = int(items[9]);
            row = [int(x) for x in items[11:]];
            if lastrow == None:
                lastrow = row;
                lastsecs = asecs;
            else:
                # Try to detect seconds counter wrap
                if asecs < lastsecs:
                    if (maxseconds - lastsecs) < 60:
                        print('Possible seconds counter wrap');

                diffsecs = asecs - lastsecs;

                watts = [float(month),float(day),float(dayseconds),float(asecs),float(diffsecs)];
                watts = watts + [(a - b) / watts[4] for a,b in zip(row,lastrow)];
                if diffsecs <= 0:
                    print('Ignoring sample %d due to time warp' % sample);
                    print(watts);
                else:
                    data.append(watts);
                    lastrow = row;
                    lastsecs = asecs;

        f.close();
        print('Highest seconds counter value: %d' % lastsecs);
        return data;

if len(sys.argv) != 2:
    print('Usage: %s <raw data file name>' % sys.argv[0]);
    sys.exit(1);
else:
    # Convert raw data to numpy matrix having Watts for Mains and
    # Individual Circuits per row 
    data = array(getRawData(sys.argv[1]));
    fname = '%sOverall.npy' % os.path.splitext(sys.argv[1])[0];
    print('Data extracted to %s' % fname);
    save(fname,data);

    sys.exit(0);

          

