import sys
from numpy import *
import matplotlib.pyplot as plt
import os


tics = ['UpBath_Closets', 'West_Bdrm_Outlets', 'SEBdrm_L_O_HallOut', 'Kitchen_North_Out', 'Furnace', 'Bsmnt_Bath_Closet', 'Breaker_14', 'Dishwshr_Ctrl_Vac', 'Bsmnt_East_Out', 'Wshr_KitEastOut', 'RecFurnRm_Out', 'DngKtchLvng_FnLts', 'Dining_Room_Out', 'AirConditioner', 'LvgRmSthExt_LghtOut', 'ShedNrthExtLghtsOut', 'Microwav_KitchUpOut', 'Clothes_Dryer', 'Refrigerator', 'Garage', 'GreenEye_Monitor','Range'];


if len(sys.argv) != 5:
    print('Usage: %s <watts data file name> <when> <costPerkWhr> <print-only>' % sys.argv[0]);
    sys.exit(1);
else:
    # Load the data
    data = load(sys.argv[1]);
    costPerKwhr = float(sys.argv[3]);

    # Extract matrix of Watts per interval per individual circuit excluding range
    ind = data[:,6:];
    # Extract an estimate of range Watts per interval by subtracting total
    # individual Watts per interval from Mains Watts per interval 
    r = subtract(data[:,5],ind.sum(1));
    place(r,r<0,0);
    # Append rage data to end of individual circuit data sets
    indr = column_stack((ind,r));
    # Cast values to float
    indr = cast['f'](indr);
    # Compute kWhrs used per interval
    intervals = data[:,4].reshape(data[:,4].size,1);
    indrKwhrs = (indr/1000.0) * (intervals/3600.0);
    # Compute total kWhrs
    totalKwhrs = indrKwhrs.sum();
    # Compute percentage of total kWhrs
    totalDollarCostPerCircuit = (indrKwhrs.sum(0))*costPerKwhr;
    keys = argsort(totalDollarCostPerCircuit);
    keys = keys[::-1];
    stics = take(tics,keys);
    sTotalDollarCostPerCircuit = sort(totalDollarCostPerCircuit);
    sTotalDollarCostPerCircuit = sTotalDollarCostPerCircuit[::-1];

    plt.figure(1,figsize=(10,10));
    plt.title('%s Ordered Total Cost By Individual Circuit\nTotal Cost: $%.2f over %.2f days' % (sys.argv[2],totalKwhrs*costPerKwhr,intervals.sum()/3600.0/24.0));
    plt.ylabel('Total Cost ($)');
    plt.xlabel('Individual Circuit');
    plt.bar(range(len(tics)),sTotalDollarCostPerCircuit);
    plt.xticks(arange(len(tics))+0.5,stics,rotation='vertical',size='large');
    plt.tight_layout(pad=1.0,h_pad=1.0,w_pad=1.0);
    plt.savefig('%sCostByIndividual.png' % os.path.splitext(sys.argv[1])[0].replace('Data','Figures'),format='png',bbox_inches='tight');

    # Print only?
    if int(sys.argv[4]) == 0:
        plt.show();

    sys.exit(0);

          

