import sys
from numpy import *
import matplotlib.pyplot as plt
import os

CHANNELS     = {1: 'UpBath_Closets', \
                    2: 'West_Bdrm_Outlets', \
                    3: 'SEBdrm_L_O_HallOut', \
                    4: 'Kitchen_North_Out', \
                    5: 'Furnace', \
                    6: 'Bsmnt_Bath_Closet', \
                    7: 'Breaker_14', \
                    8: 'Dishwshr_Ctrl_Vac', \
                    9: 'Bsmnt_East_Out', \
                    10: 'Wshr_KitEastOut', \
                    11: 'RecFurnRm_Out', \
                    12: 'DngKtchLvng_FnLts', \
                    13: 'Dining_Room_Out', \
                    14: 'AirConditioner', \
                    15: 'LvgRmSthExt_LghtOut', \
                    16: 'ShedNrthExtLghtsOut', \
                    17: 'Microwav_KitchUpOut', \
                    18: 'Clothes_Dryer', \
                    19: 'Refrigerator', \
                    20: 'Garage', \
                    21: 'GreenEye_Monitor'};

if len(sys.argv) != 4:
    print('Usage: %s <watts data file name> <when> <print-only>' % sys.argv[0]);
    sys.exit(1);
else:
    # Load the data
    data = load(sys.argv[1]);
    ind = data[:,6:];
    r = subtract(data[:,5],ind.sum(1));
    place(r,r<0,0);
    indr = column_stack((ind,r));
    rows,cols = indr.shape;
    nbins = 0;
    f = 0;
    c = 0;
    # plot histograms of individual circuit readings greater than 50W
    for p in range(0,21,1):
        # Select points greater than 50.0
        points = indr[indr[:,p] > 50.0,p];
        # Ignore circuits with no samples greater than 50.0
        if size(points) > 0:
            # Compute the number of 50W bins above 50.0
            nbins = points.max()//50;

            # Comput PDF per bin and bin edge values
            h, e = histogram(points,bins=arange(50.0,(nbins+1)*50.0,50.0),density=True);
            
            # Compute percentage of points per bin based on
            # probability of being in a particular bin 
            h = h * 50.0;
            # Create figures with 6 subplots per figure
            plt.figure(c/6+1,figsize=(15,10));
            # Determine subplot placement
            plt.subplot(3,2,c%6+1)
            # Configure plot
            plt.tight_layout(h_pad=1.08,w_pad=0.8);
            plt.title('%s %s Percent Usage\nMin: %.2f Max: %.2f' % (sys.argv[2],CHANNELS[p+1],points.min(),points.max()));
            plt.ylabel('Percent');
            plt.xlabel('Usage Bin in Watts');
            # Plot as bar graph
            plt.bar(e[1:]-50,h*100.0,width=50.0);
            # Save each figure as PNG file
            if (c+1)%6 == 0:
                plt.savefig('%sIndividualHistogram_%d.png' % (os.path.splitext(sys.argv[1])[0].replace('Data','Figures'),c/6+1),format='png',bbox_inches='tight');

            # Count circuits plotted
            c += 1;
    # Save last figure and show all
    plt.savefig('%sIndividualHistogram_%d.png' % (os.path.splitext(sys.argv[1])[0].replace('Data','Figures'),c/6+1),format='png',bbox_inches='tight');

    # Print only?
    if int(sys.argv[3]) == 0:
        plt.show();

    sys.exit(0);

          

