import sys
from numpy import *
import matplotlib.pyplot as plt
import os

tics = ['UpBath_Closets', 'West_Bdrm_Outlets', 'SEBdrm_L_O_HallOut', 'Kitchen_North_Out', 'Furnace', 'Bsmnt_Bath_Closet', 'Breaker_14', 'Dishwshr_Ctrl_Vac', 'Bsmnt_East_Out', 'Wshr_KitEastOut', 'RecFurnRm_Out', 'DngKtchLvng_FnLts', 'Dining_Room_Out', 'AirConditioner', 'LvgRmSthExt_LghtOut', 'ShedNrthExtLghtsOut', 'Microwav_KitchUpOut', 'Clothes_Dryer', 'Refrigerator', 'Garage', 'GreenEye_Monitor','Range'];

if len(sys.argv) != 4:
    print('Usage: %s <watts data file name> <when> <print-only>' % sys.argv[0]);
    sys.exit(1);
else:
    # Load the data
    data = load(sys.argv[1]);

    ind = data[:,6:];
    # Compute range circuit from difference between mains and total
    # individual and append to individual dataset
    r = subtract(data[:,5],ind.sum(1));
    place(r,r<0,0);
    indr = column_stack((ind,r));
    # Cast values to float
    indr = cast['f'](indr);
    # Compute kWhrs used per interval
    intervals = data[:,4].reshape(data[:,4].size,1);
    indrKwhrs = (indr/1000.0) * (intervals/3600.0);
    # Compute total kWhrs
    totalKwhrs = indrKwhrs.sum();
    # Compute percentage of total kWhrs
    pcntusage = ((indrKwhrs.sum(0))/totalKwhrs)*100.0;
    keys = argsort(pcntusage);
    keys = keys[::-1];
    stics = take(tics,keys);
    spcntusage = sort(pcntusage);
    spcntusage = spcntusage[::-1];

    plt.figure(1,figsize=(10,10));
    plt.title('%s Ordered Percent Usage By Individual Circuit\nTotal kWhrs: %.2f over %.2f days' % (sys.argv[2],totalKwhrs,intervals.sum()/3600.0/24.0));
    plt.ylabel('Percent Of Total kWhrs');
    plt.xlabel('Individual Circuit');
    plt.bar(range(len(tics)),spcntusage);
    plt.xticks(arange(len(tics))+0.5,stics,rotation='vertical',size='large');
    plt.tight_layout(pad=1.0,h_pad=1.0,w_pad=1.0);
    plt.savefig('%sPercentUsageByIndividual.png' % os.path.splitext(sys.argv[1])[0].replace('Data','Figures'),format='png',bbox_inches='tight');

    # Print only?
    if int(sys.argv[3]) == 0:
        plt.show();

    sys.exit(0);

          

