from numpy import *
from scipy import ndimage
import sys
import os
import matplotlib.pyplot as plt
from mpl_toolkits.mplot3d import Axes3D
from matplotlib import cm
from matplotlib import colors


if len(sys.argv) != 5:
    print('Usage: %s <averages> <sigmas> <circuit> <print-only>' % sys.argv[0]);
    sys.exit(1);

averages = load(sys.argv[1]);
sigmas = load(sys.argv[2]);

plt.figure(figsize=(16,12),dpi=80);

plt.subplots_adjust(top=.98, wspace=.25,hspace=.25);
plt.subplot(3,2,1);
plt.imshow(averages, cmap=cm.jet);
plt.yticks(arange(7),('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday'));
plt.xlabel('Hour Of Day');
plt.ylabel('Day Of Week');
plt.title('Average %s kWhr Usage' % sys.argv[3]);
plt.colorbar();

plt.subplot(3,2,2);
plt.imshow(sigmas, cmap=cm.jet);
plt.yticks(arange(7),('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday'));
plt.xlabel('Hour Of Day');
plt.ylabel('Day Of Week');
plt.title('Sigma %s kWhr Usage' % sys.argv[3]);
plt.colorbar();

plt.subplot(3,2,3);
y = averages.mean(axis=0);
plt.bar(range(averages.shape[1]),y, align='center');
plt.ylim([0.0,y.max()+0.5*(y.max()-y.min())]);
plt.xlim([0.0,23.0]);
plt.ylabel('Mean Average Hourly Usage (kWhr)');
plt.title('Mean Average %s kWhr Usage By Hour' % sys.argv[3]);
ax = plt.gca();
ax.set_xticklabels([]);

plt.subplot(3,2,5);
plt.bar(range(sigmas.shape[1]),sigmas.mean(axis=0), align='center');
plt.ylim([0.0,y.max()+0.5*(y.max()-y.min())]);
plt.xlim([0.0,23.0]);
plt.xlabel('Hour Of Day');
plt.ylabel('Mean Sigma Hourly Usage (kWhr)');
plt.title('Mean Sigma %s kWhr Usage By Hour' % sys.argv[3]);

plt.subplot(3,2,4);
y = averages.mean(axis=1);
plt.bar(range(averages.shape[0]),y, align='center');
plt.ylim([0.0,y.max()+0.5*(y.max()-y.min())]);
plt.xticks(arange(7),('Mon','Tues','Wed','Thurs','Fri','Sat','Sun'));
plt.ylabel('Mean Average Daily Usage (kWhr)');
plt.title('Mean Average %s kWhr Usage By Day' % sys.argv[3]);
ax = plt.gca();
ax.set_xticklabels([]);

plt.subplot(3,2,6);
plt.bar(range(sigmas.shape[0]),sigmas.mean(axis=1), align='center');
plt.ylim([0.0,y.max()+0.5*(y.max()-y.min())]);
plt.xticks(arange(7),('Mon','Tue','Wed','Thur','Fri','Sat','Sun'));
plt.xlabel('Day Of Week');
plt.ylabel('Mean Sigma Daily Usage (kWhr)');
plt.title('Mean Sigma %s kWhr Usage By Day' % sys.argv[3]);
#print('%s.png' % os.path.splitext(sys.argv[1])[0].replace('_averages',''));
plt.savefig('%s.png' % os.path.splitext(sys.argv[1])[0].replace('_averages','').replace('Data','Figures'),format='png',bbox_inches='tight');

# Print only?
if int(sys.argv[4]) == 0:
    plt.show();


