import sys
from numpy import *
from calendar import *
import os

CHANNELS     = {1: 'UpBath_Closets', \
                    2: 'West_Bdrm_Outlets', \
                    3: 'SEBdrm_L_O_HallOut', \
                    4: 'Kitchen_North_Out', \
                    5: 'Furnace', \
                    6: 'Bsmnt_Bath_Closet', \
                    7: 'Breaker_14', \
                    8: 'Dishwshr_Ctrl_Vac', \
                    9: 'Bsmnt_East_Out', \
                    10: 'Wshr_KitEastOut', \
                    11: 'RecFurnRm_Out', \
                    12: 'DngKtchLvng_FnLts', \
                    13: 'Dining_Room_Out', \
                    14: 'AirConditioner', \
                    15: 'LvgRmSthExt_LghtOut', \
                    16: 'ShedNrthExtLghtsOut', \
                    17: 'Microwav_KitchUpOut', \
                    18: 'Clothes_Dryer', \
                    19: 'Refrigerator', \
                    20: 'Garage', \
                    21: 'GreenEye_Monitor'};

class sparseMatrix:
    def __init__(self):
        self.elements = {};

    def addValue(self, tuple, value):
        self.elements[tuple] = value;

    def getValue(self,tuple):
        try:
            value = self.elements[tuple];
        except KeyError:
            value = -1.0;
        return value;

def reformDay(prevhr, iday, imonth):

    if prevhr == 23:
        if iday == 1:
            if imonth in [1,2,4,6,8,9,11]:
                iday = 31;
                if imonth == 1:
                    imonth = 12;
                else:
                    imonth -= 1;
            elif imonth in [5,7,10,12]:
                iday = 30;
                imonth -= 1;
            else:
                iday = 28;
                imonth -= 1;
        else:
            iday -= 1;

    return (iday,imonth);


if len(sys.argv) != 2:
    print('Usage: %s <watts data file name>' % sys.argv[0]);
    sys.exit(1);
else:
    # Load the data 
    data = load(sys.argv[1]);

    # Select columns month, day, dayseconds, diffsecs, mains watts
    data = data[:,(0,1,2,4)+tuple(range(6,data.shape[1],1))];

    sparse = sparseMatrix();
    month_day = [];
    # Create a table with rows that look like the following
    #
    #   month, day, hour, kWhr
    #
    prevhr = -1;
    firstHour = True;
    total_kWhr = [];
    hrseconds = 0.0;
    valid_rows = 0;
    prevday = 0;
    for row in data:
        (month, day, daysec, diffsec) = row[0:4];
        wsec = row[4:];
        hour = int(daysec / 3600);

#        print('$$$ %d,%d,%d,%d,%d' % (int(month),int(day),int(daysec),int(diffsec),int(mainwsec)));

        if prevhr < 0:
            prevhr = hour;
            continue;

        if hour != prevhr and firstHour:
            valid_rows += 1;
            thishr_seconds = daysec % 3600.0;
#            print('thishr_seconds = %.2f' % thishr_seconds);
            hrseconds += thishr_seconds;
            for iwsec in wsec:
                thishr_wattsec = (iwsec * (thishr_seconds / diffsec));
                total_kWhr.append(((thishr_wattsec * (thishr_seconds / 3600.0)) / 1000.0));

#            print('<<<%d,%d,%d,%d,%.4f' % (int(month),int(day),prevhr,int(hrseconds),total_kWhr));

            prevhr = hour;
            firstHour = False;
            continue;
        elif firstHour:
            continue;

        if hour != prevhr:
            valid_rows += 1;
            # Process previous hour worth of data. 

            # Partition the last interval according to where the
            # crossing occured
            thishr_seconds = daysec % 3600.0;
            lasthr_seconds = diffsec - thishr_seconds;
#            print('lasthr_seconds = %.2f' % lasthr_seconds);
            hrseconds += lasthr_seconds;
            (iday,imonth) = reformDay(prevhr, int(day),int(month));
            count = 0;
            lasthr_wattsec = [];
            for iwsec in wsec:
                lasthr_wattsec.append((iwsec * (lasthr_seconds / diffsec)));
                # print('lasthr_wattsec = %.2f' % lasthr_wattsec);
                total_kWhr[count] += \
                    ((lasthr_wattsec[count] * (lasthr_seconds / 3600.0)) / 1000.0);
                sparse.addValue((imonth,iday,prevhr,count),total_kWhr[count]);
                count += 1;
#               print('%d,%d,%d,%.4f\n' % (imonth,iday,prevhr,total_kWhr));

            if iday != prevday:
                month_day.append([imonth,iday]);
                prevday = iday;
            prevhr = hour;
#            print('thishr_seconds = %.2f' % thishr_seconds);
            hrseconds = thishr_seconds;
            count = 0;
            for iwsec in wsec:
                thishr_wattsec = iwsec - lasthr_wattsec[count];
#            print('thishr_wattsec = %.2f' % thishr_wattsec);
                total_kWhr[count] = \
                    ((thishr_wattsec * (thishr_seconds / 3600.0)) / 1000.0);
                count += 1;

            
        # Process data in the current hour
        else:
            valid_rows += 1;
#            print('thishr_seconds = %.2f' % diffsec);
#            print('thishr_wattsec = %.2f' % mainwsec);
            hrseconds += diffsec;
            count = 0;
            for iwsec in wsec:
                total_kWhr[count] += ((iwsec * (diffsec / 3600.0)) / 1000.0);
                count += 1;
#            print('<<<%d,%d,%d,%d,%.4f' % (int(month),int(day),prevhr,int(hrseconds),total_kWhr));

    summary = zeros((len(month_day),26,count));
    for circuit in range(count):
        row = 0;
        for md in month_day:
            summary[row][0][circuit] = md[0];
            summary[row][1][circuit] = md[1];
            for hour in range(24):
                summary[row][hour+2][circuit] = sparse.getValue((md[0],md[1],hour,circuit));
            row += 1;
            

    for circuit in range(count):
        f = open('%s_%sDoW.csv' % (os.path.splitext(sys.argv[1])[0],CHANNELS[circuit+1]), 'w');
        for row in summary[:,:,circuit]:
            f.write('%s,%s,%s\n' % (','.join('%d' % int(x) for x in row[0:2]),day_name[weekday(2013,int(row[0]),int(row[1]))],','.join('%.4f' % x for x in row[2:])));
        f.close();

sys.exit(0);

          

