import traceback
import sys
from numpy import *
from calendar import *
import os

class sparseMatrix:
    def __init__(self):
        self.elements = {};

    def addValue(self, tuple, value):
        self.elements[tuple] = value;

    def getValue(self,tuple):
        try:
            value = self.elements[tuple];
        except KeyError:
            value = -1.0;
        return value;


if len(sys.argv) != 2:
    print('Usage: %s <watts data file name>' % sys.argv[0]);
    sys.exit(1);
else:
    # Load the data 
    data = load(sys.argv[1]);

    # Select columns month, day, dayseconds, diffsecs, mains watts
    data = data[:,(0,1,2,4,5)];
    month_day = [];

    sparse = sparseMatrix();

    # Create a table with rows that look like the following
    #
    #   month, day, hour, kWhr
    #
    prevhr = -1;
    firstHour = True;
    total_kWhr = 0.0;
    hrseconds = 0.0;
    prevday = 0;

    for row in data:
        (month, day, daysec, diffsec, mainwsec) = row;
        hour = int(daysec / 3600);

#        print('$$$ %d,%d,%d,%d,%d' % (int(month),int(day),int(daysec),int(diffsec),int(mainwsec)));

        if prevhr < 0:
            prevhr = hour;
            continue;

        if hour != prevhr and firstHour:
            thishr_seconds = daysec % 3600.0;
#            print('thishr_seconds = %.2f' % thishr_seconds);
            hrseconds += thishr_seconds;
            thishr_wattsec = (mainwsec * (thishr_seconds / diffsec));
            total_kWhr = \
                ((thishr_wattsec * (thishr_seconds / 3600.0)) / 1000.0);
#            print('<<<%d,%d,%d,%d,%.4f' % (int(month),int(day),prevhr,int(hrseconds),total_kWhr));
            prevhr = hour;
            firstHour = False;
            continue;
        elif firstHour:
            continue;

        if hour != prevhr:
            # Process previous hour worth of data. 

            # Partition the last interval according to where the
            # crossing occured
            thishr_seconds = daysec % 3600.0;
            lasthr_seconds = diffsec - thishr_seconds;
#            print('lasthr_seconds = %.2f' % lasthr_seconds);
            hrseconds += lasthr_seconds;
            lasthr_wattsec = (mainwsec * (lasthr_seconds / diffsec));
#            print('lasthr_wattsec = %.2f' % lasthr_wattsec);
            total_kWhr += \
                ((lasthr_wattsec * (lasthr_seconds / 3600.0)) / 1000.0);

            iday = int(day);
            imonth = int(month);

            if prevhr == 23:
                if iday == 1:
                    if imonth in [1,2,4,6,8,9,11]:
                        iday = 31;
                        if imonth == 1:
                            imonth = 12;
                        else:
                            imonth -= 1;
                    elif imonth in [5,7,10,12]:
                        iday = 30;
                        imonth -= 1;
                    else:
                        iday = 28;
                        imonth -= 1;
                else:
                    iday -= 1;


#            print('%d,%d,%d,%.4f\n' % (imonth,iday,prevhr,total_kWhr));

            sparse.addValue((imonth,iday,prevhr),total_kWhr);

            if iday != prevday:
                month_day.append([imonth,iday]);
                prevday = iday;

            prevhr = hour;
#            print('thishr_seconds = %.2f' % thishr_seconds);
            thishr_wattsec = mainwsec - lasthr_wattsec;
            hrseconds = thishr_seconds;
#            print('thishr_wattsec = %.2f' % thishr_wattsec);
            total_kWhr = \
                ((thishr_wattsec * (thishr_seconds / 3600.0)) / 1000.0);

            
        # Process data in the current hour
        else:
#            print('thishr_seconds = %.2f' % diffsec);
#            print('thishr_wattsec = %.2f' % mainwsec);
            hrseconds += diffsec;
            total_kWhr += ((mainwsec * (diffsec / 3600.0)) / 1000.0);
#            print('<<<%d,%d,%d,%d,%.4f' % (int(month),int(day),prevhr,int(hrseconds),total_kWhr));

    summary = zeros((len(month_day),26));
    row = 0;
    for md in month_day:
        summary[row][0] = md[0];
        summary[row][1] = md[1];
        for hour in range(24):
            summary[row][hour+2] = sparse.getValue((md[0],md[1],hour));
        row += 1;
            

    
    f = open('%s_mainsdow.csv' % os.path.splitext(sys.argv[1])[0],'w');
    for row in summary[:,:]:
        try:
            f.write('%s,%s,%s\n' % (','.join('%d' % int(x) for x in row[0:2]),day_name[weekday(2013,int(row[0]),int(row[1]))],','.join('%.4f' % x for x in row[2:])));
        except:
            traceback.print_exc();
            print(row);
    f.close();

sys.exit(0);

          

